@@ -620,15 +620,16 @@ eoo <- function(spData){
 #' Area of Occupancy (AOO).
 #' @description Calculates the Area of Occupancy of a species based on either known records or predicted distribution.
 #' @param spData One of three options: 1) matrix of longitude and latitude (two columns) of each occurrence record; 2) matrix of easting and northing (two columns, e.g. UTM) of each occurrence record in meters;  3) RasterLayer object of predicted distribution (either 0/1 or probabilistic values).
-#' @details AOO is calculated as the area of all known or predicted cells for the species. The resolution will be 2x2km as required by IUCN.
+#' @param cellSize A numeric value in km determining the side of the grid square used to calculate AOO. 
+#' @details AOO is calculated as the area of all known or predicted cells for the species. By default the resolution will be 2x2km as required by the IUCN.
 #' @return A single value in km2 or a vector with lower confidence limit, consensus and upper confidence limit (probabilities 0.975, 0.5 and 0.025 respectively).
 #' @examples
 #' range = red.examples("red.range")
 #' aoo(range)
 #' @export
-aoo <- function(spData){
+aoo <- function(spData, cellSize = 2){
   if (is(spData, "SpatRaster")){ #if rasterlayer
-    if(sum(terra::minmax(spData)) == 0){  #if no data (empty raster)
+    if (sum(terra::minmax(spData)) == 0){  #if no data (empty raster)
       area = 0
     } else if(!all(terra::as.matrix(spData) == floor(terra::as.matrix(spData)), na.rm = TRUE)){ #if probabilistic map
       upMap <- terra::classify(
@@ -652,9 +653,9 @@ aoo <- function(spData){
       area <- c(eoo(downMap), eoo(consensusMap), eoo(upMap))
     } else {
       if (terra::xmax(spData) <= 180) {  #if longlat data
-        if(terra::res(spData)[1] > 0.05){ #if resolution is > 1km use area of cells rounded to nearest 4km
+        if (terra::res(spData)[1] > 0.05){ #if resolution is > 1km use area of cells rounded to nearest 4km
           area = round(terra::global(
-            (terra::cellSize(spData, unit = "km") * spData), fun = "sum", na.rm = T)/4)*4  
+            (terra::cellSize(spData, unit = "km") * spData), fun = "sum", na.rm = T)/(cellSize^2))*(cellSize^2)
         } else {
           spData[spData < 1] <- NA
           spData <- terra::as.points(spData)
@@ -662,12 +663,12 @@ aoo <- function(spData){
                                y = terra::crds(spData)[,2])
 
           if(nrow(unique(spData)) == 1){
-            area = 4
+            area = (cellSize^2)
           } else {
             spData <- longlat2utm(spData)
-            spData = floor(spData/2000)
+            spData = floor(spData/(cellSize * 1000))
             ncells = nrow(unique(spData))
-            area = ncells * 4
+            area = ncells * (cellSize^2)
           }
         }
       } else { #if square data in meters
@@ -675,21 +676,21 @@ aoo <- function(spData){
         spData <- terra::as.points(spData) # rasterToPoints(spData)
         spData <- data.frame(x = terra::crds(spData)[,1],
                              y = terra::crds(spData)[,2])
-        spData = floor(spData/2000)
+        spData = floor(spData/(cellSize * 1000))
         ncells = nrow(unique(spData))
-        area = ncells * 4
+        area = ncells * (cellSize^2)
       }
     }
   } else if (ncol(spData) == 2){
     if (max(spData) <= 180) {  #if longlat data
       spData <- longlat2utm(spData)
-      spData = floor(spData/2000)
+      spData = floor(spData/(cellSize * 1000)) # adjust for UTM unit (meters) and cell size (cell)
       ncells = nrow(unique(spData))
-      area = ncells * 4
+      area = ncells * (cellSize^2)
     } else { #if square data in meters
-      spData = floor(spData/2000)
+      spData = floor(spData/(cellSize * 1000))
       ncells = nrow(unique(spData))
-      area = ncells * 4
+      area = ncells * (cellSize^2)
     }
   } else {
     return(warning("Data format not recognized!"))
